@@ -64,7 +64,7 @@ class BaseWorker(Shepherd):
 
         self.info("Connecting to \"%s\" using SQLAlchemy" % connstr)
 
-        self.sqlalchemy_db_maker = sessionmaker(bind=engine, autoflush=autoflush, autocommit=True)
+        self.sqlalchemy_db_maker = sessionmaker(bind=engine, autoflush=autoflush)
         self.db = scoped_session(self.sqlalchemy_db_maker)
 
     def connect_to_redis(self):
@@ -144,7 +144,7 @@ class BaseWorker(Shepherd):
 class HolmesWorker(BaseWorker):
     def initialize(self):
         self.uuid = uuid4().hex
-        self.working_url =  None
+        self.working_url = None
 
         self.facters = self._load_facters()
         self.validators = self._load_validators()
